
package MyElements::GetSpecificCookieResponse;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.fullerdata.com/FortuneCookie/FortuneCookie.asmx' }

__PACKAGE__->__set_name('GetSpecificCookieResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %GetSpecificCookieResult_of :ATTR(:get<GetSpecificCookieResult>);

__PACKAGE__->_factory(
    [ qw(        GetSpecificCookieResult

    ) ],
    {
        'GetSpecificCookieResult' => \%GetSpecificCookieResult_of,
    },
    {
        'GetSpecificCookieResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
    },
    {

        'GetSpecificCookieResult' => 'GetSpecificCookieResult',
    }
);

} # end BLOCK






} # end of BLOCK



1;


=pod

=head1 NAME

MyElements::GetSpecificCookieResponse

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
GetSpecificCookieResponse from the namespace http://www.fullerdata.com/FortuneCookie/FortuneCookie.asmx.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * GetSpecificCookieResult

 $element->set_GetSpecificCookieResult($data);
 $element->get_GetSpecificCookieResult();




=back


=head1 METHODS

=head2 new

 my $element = MyElements::GetSpecificCookieResponse->new($data);

Constructor. The following data structure may be passed to new():

 {
   GetSpecificCookieResult =>  $some_value, # string
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

